package com.ruoyi.branch.mapper;

import java.util.List;
import com.ruoyi.branch.domain.TBranchStudy;

/**
 * 支部党课学习Mapper接口
 * 
 * @author ruoyi
 * @date 2023-06-09
 */
public interface TBranchStudyMapper 
{
    /**
     * 查询支部党课学习
     * 
     * @param studyId 支部党课学习主键
     * @return 支部党课学习
     */
    public TBranchStudy selectTBranchStudyByStudyId(Long studyId);

    /**
     * 查询支部党课学习列表
     * 
     * @param tBranchStudy 支部党课学习
     * @return 支部党课学习集合
     */
    public List<TBranchStudy> selectTBranchStudyList(TBranchStudy tBranchStudy);

    /**
     * 新增支部党课学习
     * 
     * @param tBranchStudy 支部党课学习
     * @return 结果
     */
    public int insertTBranchStudy(TBranchStudy tBranchStudy);

    /**
     * 修改支部党课学习
     * 
     * @param tBranchStudy 支部党课学习
     * @return 结果
     */
    public int updateTBranchStudy(TBranchStudy tBranchStudy);

    /**
     * 删除支部党课学习
     * 
     * @param studyId 支部党课学习主键
     * @return 结果
     */
    public int deleteTBranchStudyByStudyId(Long studyId);

    /**
     * 批量删除支部党课学习
     * 
     * @param studyIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTBranchStudyByStudyIds(Long[] studyIds);
}
